==> print_color-3.0.0-dev.1.tar.gz: lib/print_color.dart <==
import 'package:ansicolor/ansicolor.dart';

// ---- console colors ---- //
AnsiPen _green = new AnsiPen()..green();
AnsiPen _red = new AnsiPen()..red();
AnsiPen _white = new AnsiPen()..white();
AnsiPen _blue = new AnsiPen()..blue();
AnsiPen _yellow = new AnsiPen()..yellow();
AnsiPen _black = new AnsiPen()..black();
AnsiPen _cyan = new AnsiPen()..cyan();
AnsiPen _magenta = new AnsiPen()..magenta();
AnsiPen _gray = new AnsiPen()..gray();

///------------------------------------
/// Print.color()
///------------------------------------
class Print {
  static final pattern = RegExp('.{1,800}');

  ///------------------------------------
  /// Print to console in white
  ///------------------------------------
  static white(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_white(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in black
  ///------------------------------------
  static black(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_black(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in gray
  ///------------------------------------
  static gray(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_gray(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in cyan
  ///------------------------------------
  static cyan(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_cyan(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in blue
  ///------------------------------------
  static blue(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_blue(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in green
  ///------------------------------------
  static green(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_green(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in red
  ///------------------------------------
  static red(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_red(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in magenta
  ///------------------------------------
  static magenta(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_magenta(match.group(0).toString())));
  }

  ///------------------------------------
  /// Print to console in yellow
  ///------------------------------------
  static yellow(text) {
    return pattern
        .allMatches(text)
        .forEach((match) => print(_yellow(match.group(0).toString())));
  }
}

==> print_color-3.0.1.tar.gz: lib/print_color.dart <==
import 'dart:developer';

///------------------------------------
/// Print.color()
///------------------------------------
class Print {
  ///------------------------------------
  /// Print to console in black
  ///------------------------------------
  static black(text) => log('\x1B[30m$text\x1B[0m', name: 'black');

  ///------------------------------------
  /// Print to console in red
  ///------------------------------------
  static red(text) => log('\x1B[31m$text\x1B[0m', name: 'red');

  ///------------------------------------
  /// Print to console in green
  ///------------------------------------
  static green(text) => log('\x1B[32m$text\x1B[0m', name: 'green');

  ///------------------------------------
  /// Print to console in yellow
  ///------------------------------------
  static yellow(text) => log('\x1B[33m$text\x1B[0m', name: 'yellow');

  ///------------------------------------
  /// Print to console in blue
  ///------------------------------------
  static blue(text) => log('\x1B[34m$text\x1B[0m', name: 'blue');

  ///------------------------------------
  /// Print to console in magenta
  ///------------------------------------
  static magenta(text) => log('\x1B[35m$text\x1B[0m', name: 'magenta');

  ///------------------------------------
  /// Print to console in cyan
  ///------------------------------------
  static cyan(text) => log('\x1B[36m$text\x1B[0m', name: 'cyan');

  ///------------------------------------
  /// Print to console in white
  ///------------------------------------
  static white(text) => log('\x1B[37m$text\x1B[0m', name: 'white');
}
